sciplot.ui package
==================

Subpackages
-----------

.. toctree::

    sciplot.ui.models
    sciplot.ui.qt5-creator

Submodules
----------

sciplot.ui.dialogs module
-------------------------

.. automodule:: sciplot.ui.dialogs
    :members:
    :undoc-members:
    :show-inheritance:

sciplot.ui.qt\_Plotter module
-----------------------------

.. automodule:: sciplot.ui.qt_Plotter
    :members:
    :undoc-members:
    :show-inheritance:

sciplot.ui.widget\_mpl module
-----------------------------

.. automodule:: sciplot.ui.widget_mpl
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: sciplot.ui
    :members:
    :undoc-members:
    :show-inheritance:
